@@ -48,6 +48,7 @@ use Net::FullAuto::Cloud::fa_amazon;
 use Net::FullAuto::FA_Core qw[$localhost];
 use File::HomeDir;
 use URI::Escape::XS qw/uri_escape/;
+use JSON::XS;
 my $home_dir=File::HomeDir->my_home;
 $home_dir||=$ENV{'HOME'}||'';
 $home_dir.='/';
@@ -233,7 +234,6 @@ if ($do==1) {
          }
       }
    }
-
    my $z=1;
    while ($z==1) {
       ($stdout,$stderr)=$handle->cmd("ps -ef",'__display__');
@@ -299,6 +299,24 @@ if ($do==1) {
    ($stdout,$stderr)=$handle->cmd("make",'__display__');
    ($stdout,$stderr)=$handle->cmd($sudo."make install",'__display__');
    ($stdout,$stderr)=$handle->cwd('~/WordPress/deps');
+   ($stdout,$stderr)=$handle->cmd("wget --version");
+   $stdout=~s/^.*?\d[.](\d+).*$/$1/s;
+   if ($stdout<18 && !(-e '/usr/local/bin/wget')) {
+      ($stdout,$stderr)=$handle->cmd($sudo.
+         "wget --random-wait --progress=dot ".
+         "https://ftp.gnu.org/gnu/wget/wget-1.19.2.tar.gz",
+         '__display__');
+      ($stdout,$stderr)=$handle->cmd($sudo.
+         "tar zxvf wget-1.19.2.tar.gz",'__display__');
+      ($stdout,$stderr)=$handle->cwd("wget-1.19.2");
+      ($stdout,$stderr)=$handle->cmd($sudo.
+         "./configure --prefix=/usr/local ".
+         "--sysconfdir=/etc --with-ssl=openssl",
+         '__display__');
+      ($stdout,$stderr)=$handle->cmd($sudo.
+         "make && make install",'__display__');
+   }
+   ($stdout,$stderr)=$handle->cwd('~/WordPress/deps');
    ($stdout,$stderr)=$handle->cmd($sudo.
       "python --version",'__display__');
    if ($stderr=~/Python /) {
@@ -605,7 +623,8 @@ print "DOING NGINX\n";
    ($stdout,$stderr)=$handle->cmd($sudo.
       "sed -i '0,/index  index.html/{//d;}' /usr/local/nginx/nginx.conf");
    $ad="            root ${home_dir}WordPress/wordpress;%NL%".
-       "            index  index.php  index.html index.htm;";
+       '            index  index.php  index.html index.htm;%NL%'.
+       '            try_files $uri $uri/ /index.php;';
    $ad=<<END;
 sed -i '1,/location/ {/location/a\\\
 $ad
@@ -952,11 +971,82 @@ END
    ($stdout,$stderr)=$handle->cmd($cmd);
 $do=1;
 if ($do) {
+   ($stdout,$stderr)=$handle->cwd("WordPress/wordpress");
+   ($stdout,$stderr)=$handle->cmd(
+      "/usr/local/bin/wp theme install oceanwp --allow-root --activate",
+      '__display__'); 
+   # http://www.theblogmaven.com/best-wordpress-plugins/
+
+my $listt=<<'END';
+| akismet                                     | active   | none      | 4.0.1   |
+| all-in-one-wp-migration                     | active   | available | 6.60    |
+| anti-spam                                   | inactive | none      | 4.4     |
+| bbpress                                     | active   | none      | 2.5.14  |
+| better-recent-comments                      | active   | none      | 1.0.4   |
+| black-studio-tinymce-widget                 | active   | none      | 2.6.0   |
+| buddypress                                  | active   | none      | 2.9.2   |
+| commentluv                                  | active   | none      | 2.94.7  |
+| comment-redirect                            | active   | none      | 1.1.3   |
+| comment-reply-email-notification            | active   | none      | 1.3.3   |
+| contact-form-7                              | active   | none      | 4.9.1   |
+| custom-dashboard-widgets                    | active   | none      | 1.3.1   |
+| login-customizer                            | active   | none      | 1.2.0   |
+| elementor                                   | active   | none      | 1.8.5   |
+| google-analytics-dashboard-for-wp           | active   | none      | 5.1.2.2 |
+| hello                                       | inactive | none      | 1.6     |
+| hide-admin-bar-from-non-admins              | active   | none      | 1.0     |
+| jetpack                                     | active   | none      | 5.5     |
+| learnpress                                  | active   | none      | 2.1.9.3 |
+| learnpress-bbpress                          | active   | none      | 2.0     |
+| learnpress-buddypress                       | active   | none      | 2.0     |
+| maxbuttons                                  | active   | available | 6.23    |
+| meks-easy-ads-widget                        | active   | available | 2.0.2   |
+| meks-flexible-shortcodes                    | active   | none      | 1.3.1   |
+| meks-simple-flickr-widget                   | active   | none      | 1.1.3   |
+| meks-smart-author-widget                    | active   | none      | 1.1.1   |
+| meks-smart-social-widget                    | active   | available | 1.3.3   |
+| meks-themeforest-smart-widget               | active   | none      | 1.2     |
+| menu-icons                                  | active   | none      | 0.10.2  |
+| menu-icons-icomoon                          | inactive | none      | 0.3.0   |
+| nav-menu-roles                              | active   | none      | 1.9.1   |
+| ocean-custom-sidebar                        | active   | none      | 1.0.2.1 |
+| ocean-extra                                 | active   | none      | 1.3.8   |
+| ocean-posts-slider                          | active   | none      | 1.0.8   |
+| ocean-product-sharing                       | active   | none      | 1.0.4   |
+| ocean-social-sharing                        | active   | none      | 1.0.7   |
+| paid-memberships-pro                        | active   | none      | 1.9.4.1 |
+| read-more-without-refresh                   | active   | none      | 2.3     |
+| simple-share-buttons-adder                  | active   | none      | 7.3.10  |
+| simple-trackback-validation-with-topsy-bloc | active   | none      | 1.2.7   |
+| ker                                         |          |           |         |
+| text-hover                                  | active   | none      | 3.7.1   |
+| theme-my-login                              | active   | none      | 6.4.9   |
+| ultimate-member                             | inactive | none      | 1.3.88  |
+| woocommerce                                 | active   | none      | 3.2.4   |
+| woocommerce-gateway-paypal-powered-by-brain | active   | none      | 2.0.4   |
+| tree                                        |          |           |         |
+| woocommerce-services                        | active   | none      | 1.8.3   |
+| woocommerce-gateway-stripe                  | active   | none      | 3.2.3   |
+| wp-to-twitter                               | active   | none      | 3.3.1   |
+| wordpress-seo                               | active   | none      | 5.8  
+END
+
    my @wp_plugins = qw(
 
          all-in-one-wp-migration
+         bbpress
          better-recent-comments
+         black-studio-tinymce-widget
+         buddypress
+         commentluv
+         comment-redirect
+         comment-reply-email-notification
          contact-form-7
+         custom-dashboard-widgets
+         elementor
+         google-analytics-dashboard-for-wp
+         hide-admin-bar-from-non-admins
+         login-customizer
          maxbuttons
          meks-easy-ads-widget
          meks-flexible-shortcodes
@@ -964,11 +1054,20 @@ if ($do) {
          meks-smart-author-widget
          meks-smart-social-widget
          meks-themeforest-smart-widget
+         menu-icons
+         menu-icons-icomoon
+         nav-menu-roles
+         ocean-custom-sidebar
+         ocean-extra
+         ocean-posts-slider
+         ocean-product-sharing
+         ocean-social-sharing 
+         paid-memberships-pro
          read-more-without-refresh
+         simple-share-buttons-adder
+         simple-trackback-validation-with-topsy-blocker
          text-hover
-         jetpack
-         read-more-without-refresh
-         text-hover
+         theme-my-login
          woocommerce
          woocommerce-gateway-paypal-powered-by-braintree
          woocommerce-services
@@ -977,7 +1076,6 @@ if ($do) {
          wordpress-seo
 
    );
-   ($stdout,$stderr)=$handle->cwd("WordPress/wordpress");
    foreach my $plugin (@wp_plugins) {
       ($stdout,$stderr)=$handle->cmd(
          "/usr/local/bin/wp plugin install $plugin --allow-root --activate",
@@ -986,6 +1084,98 @@ if ($do) {
    ($stdout,$stderr)=$handle->cmd(
       "/usr/local/bin/wp plugin install ultimate-member --allow-root",
       '__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "wget -d -qO- --random-wait --wait=3 --no-check-certificate ".
+      "https://$ip:$avail_port/wp-admin/plugins.php?action=activate&".
+      "plugin=ultimate-member%2Findex.php&plugin_status=all&paged=1&".
+      "s&_wpnonce=340db8b559",'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "wget -d -qO- --no-check-certificate --random-wait --wait=3 ".
+      "--cookies=on --keep-session-cookies --load-cookies cookies.txt ".
+      "--save-cookies cookies.txt -d https://$ip:$avail_port/wp-login.php",
+      '__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      'curl -k --cookie-jar cookies.txt https://'.
+      $ip.':'.$avail_port.'/wp-login.php');
+   ($stdout,$stderr)=$handle->cmd(
+      'curl -v -k --cookie-jar cookies.txt --max-redirs 0 '.
+      '--data "log='.$adu.'&pwd='.$service_and_cert_password.
+      '&wp-submit=Log+In&redirect_to='.$url.
+      '%2Fwp-admin%2F&testcookie=1" https://'.$ip.':'.
+      $avail_port.'/wp-login.php');
+   ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b cookies.txt 'https://".$ip.':'.$avail_port.'/wp-admin/'.
+      "customize.php?url=".$url."%2F' ".
+      "-H 'Accept: text/html,".
+      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Host: ".$ip.':'.$avail_port."' ".
+      "-H 'Referer: https://".$ip.':'.$avail_port."/' ".
+      "-H 'Upgrade-Insecure-Requests: 1' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
+      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
+    $stdout=~s/^.*_wpCustomizeSettings = (.*?)[}][}][}].*$/$1/s;
+    my $nonce=$stdout;
+    my $uuid=$stdout;
+    $nonce=~s/^.*nonce["]:([{].*?[}]),.*$/$1/s;
+    my $nonce_hash=decode_json($nonce);
+    $uuid=~s/^.*uuid["]:["](.*?)["],.*$/$1/s;
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b cookies.txt 'https://".$ip.':'.$avail_port.'/wp-admin/'.
+      "customize.php?url=".$url."%2F&changeset_uuid=$uuid".
+      "&customize_theme=twentyseventeen&customize_messenger_channel=preview-0' ".
+      "-H 'Accept: text/html,".
+      "application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Host: ".$ip.':'.$avail_port."' ".
+      "-H 'Referer: https://".$ip.':'.$avail_port."/' ".
+      "-H 'Upgrade-Insecure-Requests: 1' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; ".
+      "Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0'");
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b cookies.txt 'https://".$ip.':'.$avail_port."/?customize_changeset_uuid=".$uuid."' ".
+      "-H 'Accept: */*' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Content-Type: application/x-www-form-urlencoded; charset=UTF-8' ".
+      "-H 'Host: ".$ip.':'.$avail_port."' ".
+      "-H 'Referer: https://".$ip.':'.$avail_port."/?customize_changeset_uuid=".$uuid."&customize_theme=twentyseventeen&customize_messenger_channel=preview-0' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0' ".
+      "-H 'X-Requested-With: XMLHttpRequest' ".
+      "--data 'wp_customize=on&nonce=".$nonce_hash->{preview}."&customize_theme=twentyseventeen&customized=%7B%22blogdescription%22%3A%22Revealing+and+Healing+the+Number+One+Cause+of+Human+Difficulty%22%7D&customize_changeset_uuid=".$uuid."&partials=%7B%22blogdescription%22%3A%5B%7B%7D%5D%7D&wp_customize_render_partials=1&action=&customized=%7B%22blogdescription%22%3A%22Revealing+and+Healing+the+Number+One+Cause+of+Human+Difficulty%22%7D'");
+print "CUSTOMIZED STDOUT=$stdout<== and STDERR=$stderr<==\n";
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b cookies.txt 'https://".$ip.':'.$avail_port."/wp-admin/admin-ajax.php' ".
+      "-H 'Accept: */*' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Connection: keep-alive' ".
+      "-H 'Content-Type: application/x-www-form-urlencoded; charset=UTF-8' ".
+      "-H 'Host: ".$ip.':'.$avail_port."' ".
+      "-H 'Referer: https://".$ip.':'.$avail_port."/wp-admin/customize.php?url=https%3A%2F%2F".$ip.':'.$avail_port."%2Fchangeset_uuid=".$uuid."' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0' ".
+      "-H 'X-Requested-With: XMLHttpRequest' ".
+      "--data 'wp_customize=on&customize_theme=twentyseventeen&nonce=".$nonce_hash->{save}."&customize_changeset_uuid=".$uuid."&customize_changeset_data=%7B%22blogdescription%22%3A%7B%22value%22%3A%22Revealing+and+Healing+the+Number+One+Cause+of+Human+Difficulty%22%7D%7D&action=customize_save&customize_preview_nonce=".$nonce_hash->{preview}."'");
+print "CUSTOMIZE_SAVE STDOUT=$stdout<== and STDERR=$stderr<==\n";
+    ($stdout,$stderr)=$handle->cmd(
+      "curl -k -L -b cookies.txt 'https://".$ip.':'.$avail_port."/wp-admin/admin-ajax.php' ".
+      "-H 'Host: ".$ip.':'.$avail_port."' ".
+      "-H 'User-Agent: Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:56.0) Gecko/20100101 Firefox/56.0' ".
+      "-H 'Accept: */*' ".
+      "-H 'Accept-Language: en-US,en;q=0.5' ".
+      "-H 'Accept-Encoding: gzip, deflate, br' ".
+      "-H 'Content-Type: application/x-www-form-urlencoded; charset=UTF-8' ".
+      "-H 'X-Requested-With: XMLHttpRequest' ".
+      "-H 'Referer: https://".$ip.':'.$avail_port."/wp-admin/customize.php?url=https%3A%2F%2F$ip%3A$avail_port%2F&changeset_uuid=$uuid' ".
+      "-H 'Connection: keep-alive' ".
+      "--data 'wp_customize=on&customize_theme=twentyseventeen&nonce=".$nonce_hash->{save}."&customize_changeset_uuid=$uuid&customized=%7B%22blogdescription%22%3A%22Revealing+and+Healing+the+Number+One+Cause+of+Human+Difficulty%22%7D&customize_changeset_status=publish&action=customize_save&customize_preview_nonce=".$nonce_hash->{preview}."'");
+
+
 }
    #($stdout,$stderr)=$handle->cmd($sudo.
    #   "sudo rsync -avP ~/wordpress/ /var/www/html/",'__display__');
